From ec01712a998b35d48be3daaf272779fdbc63cd74 Mon Sep 17 00:00:00 2001
From: alecpl <alec@alec.pl>
Date: Fri, 24 Oct 2008 03:57:21 -0400
Subject: [PATCH] - Added option 'identities_level', removed 'multiple_identities' - Allow deleting identities when multiple_identities=false (#1485435)
---
program/include/rcmail.php | 122 ++++++++++++++++++++++++++++++----------
1 files changed, 91 insertions(+), 31 deletions(-)
diff --git a/program/include/rcmail.php b/program/include/rcmail.php
index 9652420..53b4765 100644
--- a/program/include/rcmail.php
+++ b/program/include/rcmail.php
@@ -15,7 +15,7 @@
| Author: Thomas Bruederli <roundcube@gmail.com> |
+-----------------------------------------------------------------------+
- $Id: rcube_browser.php 328 2006-08-30 17:41:21Z thomasb $
+ $Id: rcmail.php 328 2006-08-30 17:41:21Z thomasb $
*/
@@ -82,6 +82,13 @@
{
$config_all = $this->config->all();
+ // initialize syslog
+ if ($this->config->get('log_driver') == 'syslog') {
+ $syslog_id = $this->config->get('syslog_id', 'roundcube');
+ $syslog_facility = $this->config->get('syslog_facility', LOG_USER);
+ openlog($syslog_id, LOG_ODELAY, $syslog_facility);
+ }
+
// set task and action properties
$this->set_task(strip_quotes(get_input_value('_task', RCUBE_INPUT_GPC)));
$this->action = asciiwords(get_input_value('_action', RCUBE_INPUT_GPC));
@@ -110,7 +117,6 @@
$_SESSION['auth_time'] = time();
$_SESSION['temp'] = true;
}
-
// create user object
$this->set_user(new rcube_user($_SESSION['user_id']));
@@ -161,10 +167,10 @@
$this->config->merge((array)$this->user->get_prefs());
}
- $_SESSION['language'] = $this->user->language = $this->language_prop($this->config->get('language'));
+ $_SESSION['language'] = $this->user->language = $this->language_prop($this->config->get('language', $_SESSION['language']));
// set localization
- setlocale(LC_ALL, $_SESSION['language'] . '.utf8');
+ setlocale(LC_ALL, $_SESSION['language'] . '.utf8', 'en_US.utf8');
}
@@ -177,7 +183,13 @@
private function language_prop($lang)
{
static $rcube_languages, $rcube_language_aliases;
-
+
+ // user HTTP_ACCEPT_LANGUAGE if no language is specified
+ if (empty($lang) || $lang == 'auto') {
+ $accept_langs = explode(',', $_SERVER['HTTP_ACCEPT_LANGUAGE']);
+ $lang = str_replace('-', '_', $accept_langs[0]);
+ }
+
if (empty($rcube_languages)) {
@include(INSTALL_PATH . 'program/localization/index.inc');
}
@@ -211,21 +223,52 @@
/**
* Get the current database connection
*
* @return object rcube_db Database connection object
*/
public function get_dbh()
{
if (!$this->db) {
- $dbclass = "rcube_" . $this->config->get('db_backend', 'mdb2');
$config_all = $this->config->all();
- $this->db = new $dbclass($config_all['db_dsnw'], $config_all['db_dsnr'], $config_all['db_persistent']);
+ $this->db = new rcube_mdb2($config_all['db_dsnw'], $config_all['db_dsnr'], $config_all['db_persistent']);
$this->db->sqlite_initials = INSTALL_PATH . 'SQL/sqlite.initial.sql';
$this->db->set_debug((bool)$config_all['sql_debug']);
$this->db->db_connect('w');
}
return $this->db;
+ }
+
+
+ /**
+ * Return instance of the internal address book class
+ *
+ * @param boolean True if the address book needs to be writeable
+ * @return object rcube_contacts Address book object
+ */
+ public function get_address_book($id, $writeable = false)
+ {
+ $contacts = null;
+ $ldap_config = (array)$this->config->get('ldap_public');
+ $abook_type = strtolower($this->config->get('address_book_type'));
+
+ if ($id && $ldap_config[$id]) {
+ $contacts = new rcube_ldap($ldap_config[$id]);
+ }
+ else if ($abook_type == 'ldap') {
+ // Use the first writable LDAP address book.
+ foreach ($ldap_config as $id => $prop) {
+ if (!$writeable || $prop['writable']) {
+ $contacts = new rcube_ldap($prop);
+ break;
+ }
+ }
+ }
+ else {
+ $contacts = new rcube_contacts($this->db, $this->user->ID);
+ }
+
+ return $contacts;
}
@@ -243,7 +286,7 @@
if (!($this->output instanceof rcube_template))
$this->output = new rcube_template($this->task, $framed);
- foreach (array('flag_for_deletion') as $js_config_var) {
+ foreach (array('flag_for_deletion','read_when_deleted') as $js_config_var) {
$this->output->set_env($js_config_var, $this->config->get($js_config_var));
}
@@ -390,7 +433,7 @@
// lowercase username if it's an e-mail address (#1484473)
if (strpos($username, '@'))
- $username = strtolower($username);
+ $username = rc_strtolower($username);
// user already registered -> overwrite username
if ($user = rcube_user::query($username, $host))
@@ -417,7 +460,7 @@
raise_error(array(
'code' => 600,
'type' => 'php',
- 'file' => "config/main.inc.php",
+ 'file' => RCMAIL_CONFIG_DIR."/main.inc.php",
'message' => "Acces denied for new user $username. 'auto_create_user' is disabled"
), true, false);
}
@@ -434,6 +477,9 @@
$_SESSION['imap_ssl'] = $imap_ssl;
$_SESSION['password'] = $this->encrypt_passwd($pass);
$_SESSION['login_time'] = mktime();
+
+ if ($_REQUEST['_timezone'] != '_default_')
+ $_SESSION['timezone'] = floatval($_REQUEST['_timezone']);
// force reloading complete list of subscribed mailboxes
$this->set_imap_prop();
@@ -604,7 +650,7 @@
*/
public function load_language($lang = null)
{
- $lang = $lang ? $this->language_prop($lang) : $_SESSION['language'];
+ $lang = $this->language_prop(($lang ? $lang : $_SESSION['language']));
// load localized texts
if (empty($this->texts) || $lang != $_SESSION['language']) {
@@ -682,7 +728,7 @@
if (!$valid || ($_SERVER['REQUEST_METHOD']!='POST' && $now - $_SESSION['auth_time'] > 300)) {
$_SESSION['last_auth'] = $_SESSION['auth_time'];
$_SESSION['auth_time'] = $now;
- setcookie('sessauth', $this->get_auth_hash(session_id(), $now));
+ rcmail::setcookie('sessauth', $this->get_auth_hash(session_id(), $now), 0);
}
}
else {
@@ -704,15 +750,8 @@
*/
public function kill_session()
{
- $user_prefs = $this->user->get_prefs();
-
- if ((isset($_SESSION['sort_col']) && $_SESSION['sort_col'] != $user_prefs['message_sort_col']) ||
- (isset($_SESSION['sort_order']) && $_SESSION['sort_order'] != $user_prefs['message_sort_order'])) {
- $this->user->save_prefs(array('message_sort_col' => $_SESSION['sort_col'], 'message_sort_order' => $_SESSION['sort_order']));
- }
-
- $_SESSION = array('language' => $USER->language, 'auth_time' => time(), 'temp' => true);
- setcookie('sessauth', '-del-', time() - 60);
+ $_SESSION = array('language' => $this->user->language, 'auth_time' => time(), 'temp' => true);
+ rcmail::setcookie('sessauth', '-del-', time() - 60);
$this->user->reset();
}
@@ -852,18 +891,39 @@
{
if (!is_array($p))
$p = array('_action' => @func_get_arg(0));
-
- if ($p['task'] && in_array($p['task'], rcmail::$main_tasks))
- $url = './?_task='.$p['task'];
- else
- $url = $this->comm_path;
-
+
+ if (!$p['task'] || !in_array($p['task'], rcmail::$main_tasks))
+ $p['task'] = $this->task;
+
+ $p['_task'] = $p['task'];
unset($p['task']);
- foreach ($p as $par => $val)
- $url .= '&'.urlencode($par).'='.urlencode($val);
-
+
+ $url = './';
+ $delm = '?';
+ foreach (array_reverse($p) as $par => $val)
+ {
+ if (!empty($val)) {
+ $url .= $delm.urlencode($par).'='.urlencode($val);
+ $delm = '&';
+ }
+ }
return $url;
}
+
+
+ /**
+ * Helper method to set a cookie with the current path and host settings
+ *
+ * @param string Cookie name
+ * @param string Cookie value
+ * @param string Expiration time
+ */
+ public static function setcookie($name, $value, $exp = 0)
+ {
+ $cookie = session_get_cookie_params();
+ setcookie($name, $value, $exp, $cookie['path'], $cookie['domain'],
+ ($_SERVER['HTTPS'] && ($_SERVER['HTTPS'] != 'off')));
+ }
}
@@ -211,21 +223,52 @@
* Get the current database connection
*
- * @return object rcube_db Database connection object
+ * @return object rcube_mdb2 Database connection object
*/
public function get_dbh()
--
Gitblit v1.9.1